<?php
/*
Plugin Name: Gravity Forms RSS Add-On
Plugin URI: http://www.seodenver.com/plugins/gravity-forms-rss/
Description: Display your form entries as an RSS feed.
Author: Katz Web Services, Inc.
Version: 1.0.1
Author URI: http://www.katzwebservices.com

Copyright 2012 Katz Web Services, Inc.  (email: info@katzwebservices.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

add_action('plugins_loaded', array('KWSGFRSS', 'export'), 99999);
add_action('init', array('KWSGFRSS', 'init'));

class KWSGFRSS {
		private static $path = "gravity-forms-rss/gravity-forms-rss.php";
		private static $name = "Gravity Forms RSS Add-On";

		function init() {
			global $pagenow;

		    if(is_admin() && $pagenow === 'plugins.php') {
				add_action("admin_notices", array('KWSGFRSS', 'is_gravity_forms_installed'), 10);
			}
			if(self::is_gravity_forms_installed(false, false) !== 1){
				add_action('after_plugin_row_' . self::$path, array('GFHighrise', 'plugin_row') );
	           return;
	        }

        	if(is_admin()){
	            //creates a new Settings page on Gravity Forms' settings screen
	            if(self::has_access("gravityforms_rss")){
	                RGForms::add_settings_page("RSS", array("KWSGFRSS", "settings_page"), "");
	            }
	        }

	        add_action("gform_editor_js", array('KWSGFRSS', 'add_form_option_js'), 1000);

	        add_filter('gform_tooltips', array('KWSGFRSS', 'add_form_option_tooltip'));

			load_plugin_textdomain('gravity-forms-subscriptions', FALSE, '/gravity-forms-rss/languages' );
		}

		public static function plugin_row(){
			$message = sprintf(__("%sGravity Forms%s is required. %sPurchase it today!%s"), "<a href='http://katz.si/gravityforms'>", "</a>", "<a href='http://katz.si/gravityforms'>", "</a>");
			self::display_plugin_message($message, true);
	    }

	    private static function display_plugin_message($message, $is_error = false){
	    	$style = '';
	        if($is_error)
	            $style = 'style="background-color: #ffebe8;"';

	        echo '</tr><tr class="plugin-update-tr"><td colspan="5" class="plugin-update"><div class="update-message" ' . $style . '>' . $message . '</div></td>';
	    }

		function export() {
			if(!self::is_rss()) { return; }
			require_once(GFCommon::get_base_path() . "/entry_detail.php");
			$form_id = (int)$_REQUEST['id'];
			$page_size = 200;
			$offset = 0;
			$entry_count = RGFormsModel::get_lead_count($form_id, "", null, null, null, null);
			$leads = RGFormsModel::get_leads($form_id,"date_created", "DESC", "", $offset, $page_size, null, null, false, null, null);
			$form = RGFormsModel::get_form_meta($form_id);

			if(!isset($form['rssToken']) || @$form['rssToken'] !== @$_REQUEST['token']) {
				wp_die( __( 'You do no have access to this form\'s RSS feed (or it may not have been configured yet).' ) );
			}
#header('Content-Type: text/plain');
ob_start();
#print_r($leads);
echo '<?xml version="1.0" encoding="ISO-8859-1" ?>
<rss version="2.0">
<channel>
  <title>'.apply_filters('gforms_rss_feed_title', 'Entries for Form #'.$form_id, $form).'</title>
  <link>'.apply_filters('gforms_rss_feed_link', admin_url(sprintf('admin.php?page=gf_entries&id=%d', $form_id)), $form).'</link>
  <description>'.apply_filters('gforms_rss_feed_title', $form['description'], $form).'</description>';

            foreach($leads as $lead){
            	echo'
           <item>
           		<title>'.apply_filters('gforms_rss_entry_title', sprintf('Entry #%d', $lead['id']), $form, $lead).'</title>
           		<guid isPermaLink="false"/>
           		<link>'.apply_filters('gforms_rss_entry_link', admin_url(sprintf('admin.php?page=gf_entries&view=entry&id=%d&lid=%d&filter=&paged=1&pos=0', $form_id, $lead['id'])), $form, $lead).'</link>
           		<pubDate>'.mysql2date('D, d M Y H:i:s +0000', $lead['date_created'], false).'</pubDate>
           		<description><![CDATA[
           	';
           		ob_start();
           		GFEntryDetail::lead_detail_grid($form, $lead, false);
           		$grid = ob_get_clean();

            	echo apply_filters('gforms_rss_entry_description', $grid, $form, $lead);

            echo '
            	]]></description>
            </item>
            ';
            }
            echo '</channel></rss>';

            $contents = ob_get_clean();

            echo $contents;
            exit();
		}

		public static function is_gravity_forms_installed($asd = '', $echo = true) {
			global $pagenow, $page; $message = '';

			$installed = 0;
			$name = self::$name;
			if(!class_exists('RGForms')) {
				if(file_exists(WP_PLUGIN_DIR.'/gravityforms/gravityforms.php')) {
					$installed = 2;
					$message .= __(sprintf('%sGravity Forms is installed but not active. %sActivate Gravity Forms%s to use the %s plugin.%s', '<p>', '<strong><a href="'.wp_nonce_url(admin_url('plugins.php?action=activate&plugin=gravityforms/gravityforms.php'), 'activate-plugin_gravityforms/gravityforms.php').'">', '</a></strong>', $name,'</p>'), 'gravity-forms-rss');
				} else {
					$installed = 0;
					$message .= <<<EOD
	<p><a href="http://katz.si/gravityforms?con=banner" title="Gravity Forms Contact Form Plugin for WordPress"><img src="http://gravityforms.s3.amazonaws.com/banners/728x90.gif" alt="Gravity Forms Plugin for WordPress" width="728" height="90" style="border:none;" /></a></p>
			<h3><a href="http://katz.si/gravityforms" target="_blank">Gravity Forms</a> is required for the $name</h3>
			<p>You do not have the Gravity Forms plugin installed. <a href="http://katz.si/gravityforms">Get Gravity Forms</a> today.</p>
EOD;
				}

				if(!empty($message) && $echo) {
					echo '<div id="message" class="updated">'.$message.'</div>';
				}
			} else {
				$installed = 1;
			}
			return $installed;
		}

		public static function is_rss(){
			if(!class_exists('RGFormsModel')) { return false; }
	        $url_info = parse_url(RGFormsModel::get_current_page_url());
	        $file_name = basename($url_info["path"]);
	        return $file_name == "preview.php" || rgget("gf_page", $_GET) == "rss";
	    }

		protected static function has_access($required_permission){
	        $has_members_plugin = function_exists('members_get_capabilities');
	        $has_access = $has_members_plugin ? current_user_can($required_permission) : current_user_can("level_7");
	        if($has_access)
	            return $has_members_plugin ? $required_permission : "level_7";
	        else
	            return false;
	    }

	    public static function settings_page(){
			$message = $validimage = false;
	        if(!empty($_POST["uninstall"])){
	            check_admin_referer("uninstall", "gf_highrise_uninstall");
	            self::uninstall();

	            ?>
	            <div class="updated fade" style="padding:20px;"><?php _e(sprintf("Gravity Forms Highrise Add-On have been successfully uninstalled. It can be re-activated from the %splugins page%s.", "<a href='plugins.php'>","</a>"), "gravityformshighrise")?></div>
	            <?php
	            return;
	        }
	        else if(!empty($_POST["gf_highrise_submit"])){
	            check_admin_referer("update", "gf_highrise_update");
	            $settings = array("url" => stripslashes($_POST["gf_highrise_url"]), "token" => stripslashes($_POST["gf_highrise_token"]));
	            update_option("gf_highrise_settings", $settings);
	        }
	        else{
	            $settings = get_option("kws_gf_rss_settings");
	        }

	        ?>
	        <style type="text/css">
	            .ul-square li { list-style: square!important; }
	            .ol-decimal li { list-style: decimal!important; }
	        </style>
			<div class="wrap">
				<h2><?php _e('Gravity Forms Highrise Add-on Settings'); ?></h2>
			<?php if($message) {
					echo "<div class='fade below-h2 {$class}'>".wpautop($message)."</div>";
				} ?>

	        <form method="post" action="">
	            <?php wp_nonce_field("update", "gf_highrise_update") ?>
	            <h3><?php _e("Highrise Account Information", "gravityformshighrise") ?></h3>
	            <p style="text-align: left;">
	                <?php _e(sprintf("If you don't have a Highrise account, you can %ssign up for one here%s", "<a href='http://highrisehq.com/' target='_blank'>" , "</a>"), "gravityformshighrise") ?>
	            </p>

				<table class="form-table">
	                <tr>
	                    <th scope="row"><label for="gf_highrise_url"><?php _e("Highrise URL", "gravityformshighrise"); ?></label> </th>
	                    <td><input type="text" size="75" id="gf_highrise_url" name="gf_highrise_url" value="<?php echo esc_attr($settings["url"]) ?>"/> <?php echo $validimage; ?> <br/> Your Highrise URL, e.g. http://yourcompany.highrisehq.com</td>
	                </tr>
	                <tr>
	                    <th scope="row"><label for="gf_highrise_token"><?php _e("API Token", "gravityformshighrise"); ?></label> </th>
	                    <td><input type="text" size="75" id="gf_highrise_token" name="gf_highrise_token" value="<?php echo esc_attr($settings["token"]) ?>"/> <?php echo $validimage; ?> <br/> Your Highrise API token can be found in Highrise under Account &amp; settings > My info in the tab named "API token".</td>
	                </tr>
	                <tr>
	                    <td colspan="2" ><input type="submit" name="gf_highrise_submit" class="button-primary" value="<?php _e("Save Settings", "gravityformshighrise") ?>" /></td>
	                </tr>

	            </table>
	            <div>

	            </div>
	        </form>

			</div>
        <?php
    }

	public static function add_form_option_tooltip($tooltips) {
		$tooltips["form_rss"] = "<h6>" . __("Access a RSS Feed of Form Entries", "gravity-forms-highrise") . "</h6>" . __("This is the access key to view form entries as an RSS feed. You can use an RSS feed reader to read the latest entries by following the 'Go to RSS Feed' link.", "gravity-forms-highrise");
		return $tooltips;
	}

	public static function add_form_option_js() {
		ob_start();
			gform_tooltip("form_rss");
			$tooltip = ob_get_contents();
		ob_end_clean();
		$tooltip = trim(rtrim($tooltip)).' ';
?>
<script>
	jQuery(document).ready(function($) {

		$('#gform_settings_tab_2 .gforms_form_settings').append("<li id='gform_rss_li'><?php echo $tooltip; ?><small class='alignright'><a id='gform_generate_new_rss_token' href='#'>Generate a New Token</a></small><label for='gform_rss_token' id='gform_rss_token_label' class='description' style='clear:left; display:block;'><?php _e("RSS Feed Token", "gravity-forms-rss") ?><input type='text' class='widefat' id='gform_rss_token' /></label></li>");

		if(!form.rssToken || form.rssToken.length === 0) {
			var token = '<?php echo sha1(rand(0,100000000).'KWSGFRSS'); ?>';
			rssNotSetup = true;
			show_rss_token_warning('active');
		} else {
			rssNotSetup = false;
			var token = form.rssToken;
		}

		set_gform_rss_token(token);

		$('#gform_generate_new_rss_token').click(function(e) {

			var r = confirm("Reset the RSS token? Previous feed URLs will no longer work.");

			if(r === true) {
				var str1 = Math.random(0, 10000000).toString(32).substr(2);
				var str2 = Math.random(0, 10000000).toString(32).substr(2);
				var str3 = Math.random(0, 10000000).toString(32).substr(2);
				var str4 = Math.random(0, 10000000).toString(32).substr(2);
				var str5 = Math.random(0, 10000000).toString(32).substr(2);
				var str6 = Math.random(0, 10000000).toString(32).substr(2);
				$("#gform_rss_token").val(str1 + str2 + str3 + str4 + str5 + str6).trigger('change');
				show_rss_token_warning('updated');
			}

			return false;
		});

		function show_rss_token_warning(type) {
			$('#gform_rss_warning').remove();
			$('#gform_rss_li').before('<li id="gform_rss_warning"><strong style="display:block;">You must save the form before the RSS token is '+type+'.</strong></li>');
		}

		function set_gform_rss_token(val) {
			if($('#gform_rss_feed_link').length) {
				$('#gform_rss_feed_link').remove();
			}

			if(rssNotSetup === false) {
				var $link = $('<a />')
					.css({
						float: 'left',
						display : 'block',
						'font-size': '1em',
						margin : '0 .5em 0 0',
						color: $('#adminmenu a').css('color')
					})
					.attr('id', 'gform_rss_feed_link')
					.attr('href', '<?php echo site_url('?gf_page=rss&id='.$_GET['id'].'&token='); ?>'+val)
					.text('Go to RSS Feed').attr('target', '_blank');

				$("#gform_rss_li").prepend($link);
			}

			$("#gform_rss_token").val(val);

			form.rssToken = val;

			SortFields(); // Update the form object to include the new rssToken setting
		}

		$("#gform_rss_token").live('change ready', function() {

			set_gform_rss_token($(this).val());

		}).trigger('ready');

		$('.tooltip_form_rss').qtip({
         content: $('.tooltip_form_rss').attr('tooltip'), // Use the tooltip attribute of the element for the content
         show: { delay: 200, solo: true },
         hide: { when: 'mouseout', fixed: true, delay: 200, effect: 'fade' },
         style: 'gformsstyle', // custom tooltip style
         position: {
      		corner: {
         		target: 'topRight'
                ,tooltip: 'bottomLeft'
      		}
  		 }
      });

	});
</script><?php
	}

}
